@@ -7,22 +7,22 @@ use GD;
 
 =head1 NAME
 
-  Bio::DOOP::Graphics::Feature - graphical representation of the features
+  Bio::DOOP::Graphics::Feature - graphical representation of the features.
 
 =head1 SYNOPSIS
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 DESCRIPTION
 
-  This object is represent a picture that is contain all the sequence features in the subset.
-  This module is enough quick to use it in your CGI scripts. You can also use it to visualize
+  This object represents a picture that contains all the sequence features of a subset.
+  The module is quick enough to use it in your CGI scripts. You can also use it to visualize
   the subset.
 
 =head1 AUTHOR
@@ -35,11 +35,11 @@ our $VERSION = '0.06';
 
   $pic = Bio::DOOP::Graphics::Feature->create($db,"1234");
 
-  Create new picture. Later you can add your own graphics element to this.
+  Create new picture. Later you can add your own graphics elements to it.
   Arguments: 
   1. Bio::DOOP::DBSQL object
   2. Subset primary id.
-  Return type: Bio::DOOP::Graphics::Feature
+  Return type: Bio::DOOP::Graphics::Feature object
 
 =cut
 
@@ -52,6 +52,7 @@ sub create {
 
   my @seqs    = @{$subset->get_all_seqs};
   my $height  = ($#seqs+1) * 70 + 40;
+
   my $width   = $subset->get_cluster->get_promo_type + 20;
   my $image   = new GD::Image($width,$height); # Create the image
 
@@ -63,14 +64,14 @@ sub create {
   $self->{POS}             = 0;
   $self->{SUBSET_ID}       = $subset->get_id;
 
-  # This is the map of the image. It is useful for generate html code
-  #TODO Later add more types to this hash
+  # This is the map of the image. It is useful for generating html code.
+  #TODO : Add more types to this hash.
   $self->{MAP}             = {
                                 motif => [],
                                 dbtss => [],
                                 utr   => []
   };
-  # The color map of the object
+  # The color map of the object.
   $self->{COLOR}           = {
                                 background => [200,200,200],
                                 label      => [0,0,0],
@@ -89,7 +90,7 @@ sub create {
   Add an RGB color to the specified drawing element.
   $image->add_color("background",200,200,200);
   $image->set_colors;
-  The available drawing elements are the following: background, label, strip, utr, motif, tss
+  The available drawing elements are the following : background, label, strip, utr, motif, tss.
 
 =cut
 
@@ -106,9 +107,8 @@ sub add_color {
 
 =head2 set_colors
 
-  Set all the usage colors. Preveously allocate colors with add_color. Use this method only ONCE after you set
-  all the colors.
-  If you use it more than one, the results will be strange.
+  Set all the colors. Allocate colors previously with add_color. Use this method only ONCE after you set
+  all the colors. If you use it more than once, results will be strange.
 
 =cut
 
@@ -119,22 +119,22 @@ sub set_colors {
   my $g;
   my $b;
   ($r,$g,$b) = @{$self->{COLOR}->{background}};
-  $self->{IMAGE}->colorAllocate($r,$g,$b);                         # Set the background color
+  $self->{IMAGE}->colorAllocate($r,$g,$b);                         # Set the background color.
   ($r,$g,$b) = @{$self->{COLOR}->{label}};
-  $self->{LABEL}      = $self->{IMAGE}->colorAllocate($r,$g,$b);   # Set the label color
+  $self->{LABEL}      = $self->{IMAGE}->colorAllocate($r,$g,$b);   # Set the label color.
   ($r,$g,$b) = @{$self->{COLOR}->{utr}};
-  $self->{UTR}        = $self->{IMAGE}->colorAllocate($r,$g,$b);   # Set the UTR color
+  $self->{UTR}        = $self->{IMAGE}->colorAllocate($r,$g,$b);   # Set the UTR color.
   ($r,$g,$b) = @{$self->{COLOR}->{motif}};
-  $self->{MOTIFCOLOR} = $self->{IMAGE}->colorAllocate($r,$g,$b);   # Set the motif color
+  $self->{MOTIFCOLOR} = $self->{IMAGE}->colorAllocate($r,$g,$b);   # Set the motif color.
   ($r,$g,$b) = @{$self->{COLOR}->{tss}};
-  $self->{TSSCOLOR}   = $self->{IMAGE}->colorAllocate($r,$g,$b);   # Set the tss color
+  $self->{TSSCOLOR}   = $self->{IMAGE}->colorAllocate($r,$g,$b);   # Set the tss color.
   ($r,$g,$b) = @{$self->{COLOR}->{strip}};
-  $self->{STRIP}      = $self->{IMAGE}->colorAllocate($r,$g,$b);   # Set the strip color
+  $self->{STRIP}      = $self->{IMAGE}->colorAllocate($r,$g,$b);   # Set the strip color.
 }
 
 =head2 add_scale
 
-  Draws scale on the picture
+  Draws scale on the picture.
 
 =cut
 
@@ -143,24 +143,24 @@ sub add_scale {
 
   my $color = $self->{LABEL};
 
-  # Draw the main axis
+  # Draw the main axis.
   $self->{IMAGE}->line(10,5,$self->{WIDTH}-10,5,$color);
 
-  # Draw the scales
+  # Draw the scales.
   my $i;
   for ($i = 20; $i < $self->{WIDTH}-10; $i += 10){
       if( ($i / 100) == int($i / 100) ) {
-          $self->{IMAGE}->line($i+10,0,$i+10,10,$color);     # Big scale
-          my $str = ($self->{WIDTH} - 20 - $i) * -1;   # The scale label
-          my $posx = $i - (length($str)/2)*5 + 10;     # Nice label positioning
+          $self->{IMAGE}->line($i+10,0,$i+10,10,$color);     # Big scale.
+          my $str = ($self->{WIDTH} - 20 - $i) * -1;   # The scale label.
+          my $posx = $i - (length($str)/2)*5 + 10;     # Nice label positioning.
           $self->{IMAGE}->string(gdTinyFont,$posx,10,$str,$color);
       }
       else {
-          $self->{IMAGE}->line($i+10,3,$i+10,7,$color); # Little scale
+          $self->{IMAGE}->line($i+10,3,$i+10,7,$color); # Little scale.
       }
   }
 
-  # Draw the arrow
+  # Draw the arrow.
   my $arrow = new GD::Polygon;
   $arrow->addPt(9,5);
   $arrow->addPt(15,2);
@@ -170,7 +170,7 @@ sub add_scale {
 
 =head2 add_bck_lines
 
-  Draws scale lines through the whole image background
+  Draws scale lines through the whole image background.
 
 =cut
 
@@ -187,7 +187,7 @@ sub add_bck_lines {
 
 =head2 add_seq
 
-  Draws a specified seq on the picture. This is an internal code, so do not use it directly
+  Draws a specified sequence on the picture. This is internal code, so do not use it directly.
 
 =cut
 
@@ -200,26 +200,26 @@ sub add_seq {
   my $x1  = $self->{WIDTH} - 10;
   my $x2  = $x1-$len;
 
-  # Draw the seq line
+  # Draw the seq line.
   $self->{IMAGE}->line($x2, $index*70+40, $x1, $index*70+40, $self->{LABEL});
 
-  # Print the seq name and the length
+  # Print the seq name and the length.
   my $text = $seq->get_taxon_name . " " . $len . " bp";
   $self->{IMAGE}->string(gdTinyFont, $x2, $index*70+30, $text, $self->{LABEL});
 
-  # Draw UTR
+  # Draw UTR.
   my $utrlen = $seq->get_utr_length;
   if ($utrlen){
       $self->{IMAGE}->filledRectangle($x1-$utrlen, $index*70+35, $x1, $index*70+45, $self->{UTR});
       $self->{IMAGE}->string(gdTinyFont, $x1-$utrlen, $index*70+36, "UTR ".$utrlen." bp", $self->{LABEL});
   }
-  # Draw Features
+  # Draw Features.
   my @features = @{$seq->get_all_seq_features};
   my $motif_Y = $index*70 + 50;
   my $shift_factor = 0;
   my $motif_count = 0;
   for my $feat (@features){
-      # Draw motifs
+      # Draw motifs.
       if( ($feat->get_type eq "con") && ($feat->get_subsetid eq $self->{SUBSET_ID})){
 if ($feat->length < 12){$shift_factor = 15 - ($shift_factor and 15)}else{$shift_factor = 0}
           my %motif_element = ($feat->get_motifid => [ $x1-$feat->get_end,
@@ -236,7 +236,7 @@ if ($feat->length < 12){$shift_factor = 15 - ($shift_factor and 15)}else{$shift_
 $motif_count++;
       }
 
-      # Draw tss
+      # Draw tss.
       if( ($feat->get_type eq "tss")){
           $self->{IMAGE}->line($x1-$feat->get_start,
                                $motif_Y+20,
@@ -261,7 +261,7 @@ $motif_count++;
 
 =head2 add_all_seq
 
-  Draws all seq from subset on the picture.
+  Draws all sequences from the subset.
 
 =cut
 
@@ -281,7 +281,7 @@ sub add_all_seq {
   print IMAGE $image->get_png;
   close IMAGE;
 
-  Returns the png image. Use this when you finish the work and would like to see the results.
+  Returns the png image. Use this when you finish the work and would like to see the result.
 
 =cut
 
@@ -293,7 +293,7 @@ sub get_png {
 
 =head2 get_image
 
-  Returns the drawed image pointer. Useful for add your own GD methods for uniq picture manipulating.
+  Returns the drawn image pointer. Useful for adding your own GD methods for uniq picture manipulation.
 
 =cut
 
@@ -304,8 +304,8 @@ sub get_image {
 
 =head2 get_map
 
-  Returns a hash of arrays of hash of arrays reference that is contain the map information.
-  Here is a real world example of how to handle this method:
+  Returns a hash of arrays of hash of arrays reference that contains the map information.
+  Here is a real world example of how to handle this method :
 
   use Bio::DOOP::DOOP;
 
@@ -313,7 +313,7 @@ sub get_image {
   $cluster = Bio::DOOP::Cluster->new($db,'81001110','500');
   $image   = Bio::DOOP::Graphics::Feature->create($db,$cluster);
 
-  for $motif (@{$image->get_map->{motif}}){ # You can use 
+  for $motif (@{$image->get_map->{motif}}){
     for $motif_id (keys %{$motif}){
        @coords = @{$$motif{$motif_id}};
        # Print out the motif primary id and the four coordinates in the picture
@@ -322,8 +322,8 @@ sub get_image {
     }
   }
   
-  It is a little bit difficult, but if you familiar with references and hash of array, you
-  will be understand.
+  It is a somewhat difficult, but if you are familiar with references and nested data structures, you
+  will understand it.
 
 =cut
 
@@ -334,7 +334,7 @@ sub get_map {
 
 =head2 get_motif_map
 
-  Returns only the arrayref of motif hashes
+  Returns only the arrayref of motif hashes.
 
 =cut
 
@@ -369,5 +369,4 @@ sub get_motif_id_by_coord {
   return(0);
 }
 
-
 1;
